"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _nodeFetch = _interopRequireDefault(require("node-fetch"));

var _checkTargetUrl = _interopRequireDefault(require("./check-target-url"));

var _moduleReplication = require("@resolve-js/module-replication");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getReplicationState = async ({
  targetApplicationUrl
}) => {
  const checkResult = (0, _checkTargetUrl.default)(targetApplicationUrl);

  if (checkResult != null) {
    return checkResult;
  }

  const defaultValues = {
    paused: false,
    iterator: null,
    successEvent: null,
    locked: false
  };

  try {
    const response = await (0, _nodeFetch.default)(`${targetApplicationUrl}${_moduleReplication.REPLICATION_STATE.endpoint}`);
    const state = await response.json();

    if (response.status >= 400) {
      var _message;

      return {
        status: 'serviceError',
        statusData: {
          name: response.statusText,
          message: (_message = state.message) !== null && _message !== void 0 ? _message : response.statusText
        },
        ...defaultValues
      };
    }

    return state;
  } catch (error) {
    if (error.name === 'AbortError' || error.name === 'FetchError' || error.name === 'TypeError') {
      return {
        status: 'serviceError',
        statusData: {
          name: error.name,
          message: error.message,
          stack: error.stack ? error.stack : null
        },
        ...defaultValues
      };
    } else {
      return {
        status: 'error',
        statusData: {
          name: error.name,
          message: error.message,
          stack: error.stack ? error.stack : null
        },
        ...defaultValues
      };
    }
  }
};

var _default = getReplicationState;
exports.default = _default;
//# sourceMappingURL=get-replication-state.js.map